@@ -12,10 +12,10 @@ class Report:
         # GET env variables.
         self.KH_REPORTING_URL = os.getenv('KH_REPORTING_URL')
         if self.loglevel == None:
-            level = 'WARNING'
+            level = logging.getLevelName('WARNING')
         else:
             level = logging.getLevelName(self.loglevel)
-            
+
         logging.basicConfig(format='%(asctime)s: %(levelname)s: %(message)s', level=level)
 
         logging.warning('Warning logging enabled')
@@ -30,7 +30,7 @@ class Report:
     def postResults(self, data):
         # Send Request:
         try:
-            logging.debug("Sending data: "+data) 
+            logging.debug("Sending data: "+str(data)) 
             r = requests.post(url = self.KH_REPORTING_URL, json=data)
             r.raise_for_status
         except requests.exceptions.HTTPError as err:
@@ -39,7 +39,7 @@ class Report:
     def success(self):
         logging.debug("Check passed")
         data = {"OK": True}
-        logging.debug("Sending Data: Ok")
+        logging.debug("Sending Data: " + str(data))
         try:
             self.postResults(data)
         except:
@@ -49,7 +49,7 @@ class Report:
         logging.debug("Check failed")
         self.message = message
         data = {"Errors": [message],"OK": False}
-        logging.debug("Sending error data: "+  message)
+        logging.debug("Sending error data: "+  str(message))
         try: 
             self.postResults(data)
         except:
